.. PyDbLite documentation master file, created by
   sphinx-quickstart on Mon Sep 15 14:19:46 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:tocdepth: 3

 .. image:: ../../doc/img/banniere.jpg
    :align: center

.. role:: python(code)
    :language: py

.. highlight:: python
   :linenothreshold: 5

.. include:: long_description.rst

.. include:: install.rst

.. toctree::
   :maxdepth: 3

   pythonengine
   sqliteengine
   api
   examples


.. toctree::
   :hidden:

   unittests
   benchmarks
   changelog
   license
   doccoverage
   contact


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
